@@ -64,8 +64,8 @@ classes for more details:
 """
 
 __ver_major__ = 0
-__ver_minor__ = 4
-__ver_patch__ = 2
+__ver_minor__ = 5
+__ver_patch__ = 1
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
                               
@@ -334,6 +334,8 @@ class Model(object):
                     cur_field_idx = idx
                     break
                 if res is PARSE_CHILDREN:
+                    if field not in fields_found:
+                        fields_found.append(field)
                     self._parse_children_ordered(child,[field],fields_found)
                     cur_field_idx = idx
                     break
@@ -364,6 +366,8 @@ class Model(object):
                         fields_found.append(field)
                     break
                 if res is PARSE_CHILDREN:
+                    if field not in fields_found:
+                        fields_found.append(field)
                     self._parse_children_unordered(child,[field],fields_found)
                     break
                 idx += 1
@@ -384,7 +388,7 @@ class Model(object):
                     err = "unknown attribute: %s" % (node.name,)
                     raise ParseError(err)
 
-    def render(self,encoding=None,fragment=False,nsmap=None):
+    def render(self,encoding=None,fragment=False,pretty=False,nsmap=None):
         """Produce XML from this model's instance data.
 
         A unicode string will be returned if any of the objects contain
@@ -406,6 +410,8 @@ class Model(object):
                 data.append('<?xml version="1.0" ?>')
         data.extend(self._render(nsmap))
         xml = "".join(data)
+        if pretty:
+            xml = minidom.parseString(xml).toprettyxml()
         if encoding:
             xml = xml.encode(encoding)
         return xml
@@ -531,7 +537,7 @@ class Model(object):
                     raise XmlError(e)
             elif isinstance(xml,unicode):
                 try:
-                    #  Try to grad the "encoding" attribute from the XML.
+                    #  Try to grab the "encoding" attribute from the XML.
                     #  It probably won't exist, so default to utf8.
                     encoding = _XML_ENCODING_RE.match(xml)
                     if encoding is None:
