@@ -1,6 +1,7 @@
 """
 
-  dexml.fields:  basic field type definitions for dexml
+dexml.fields:  basic field type definitions for dexml
+=====================================================
 
 """
 
@@ -306,7 +307,9 @@ class Value(Field):
         return val
 
     def render_value(self,val):
-        return str(val)
+        if not isinstance(val, basestring):
+            val = str(val)
+        return val
 
     def _esc_render_value(self,val):
         return escape(self.render_value(val))
@@ -502,9 +505,8 @@ class List(Field):
 
       <MyModel><list><item>one</item><item>two</item></list></MyModel>
 
-    This wrapper tag is rendered if the list is not empty and is transparent
-    for list item access.
-
+    This wrapper tag is always rendered, even if the list is empty.  It is
+    transparently removed when parsing.
     """
 
     class arguments(Field.arguments):
@@ -522,7 +524,7 @@ class List(Field):
         if not self.minlength and not self.tagname:
             self.required = False
         if self.minlength and not self.required:
-            raise ValueError("Dict must be required if it has minlength")
+            raise ValueError("List must be required if it has minlength")
 
     def _get_field(self):
         field = self.__dict__["field"]
@@ -572,8 +574,7 @@ class List(Field):
     def parse_done(self,obj):
         items = self.__get__(obj)
         if self.minlength is not None and len(items) < self.minlength:
-            if self.required or len(items) != 0:
-                raise dexml.ParseError("Field '%s': not enough items" % (self.field_name,))
+            raise dexml.ParseError("Field '%s': not enough items" % (self.field_name,))
         if self.maxlength is not None and len(items) > self.maxlength:
             raise dexml.ParseError("Field '%s': too many items" % (self.field_name,))
 
@@ -591,15 +592,15 @@ class List(Field):
                 for data in self.field.render_children(obj,item,nsmap):
                     yield data
             if self.minlength is not None and num_items < self.minlength:
-                if self.required:
-                    msg = "Field '%s': not enough items" % (self.field_name,)
-                    raise dexml.RenderError(msg)
+                msg = "Field '%s': not enough items" % (self.field_name,)
+                raise dexml.RenderError(msg)
         chunks = child_chunks()
         #  Render each chunk, but suppress the wrapper tag if there's no data.
         try:
             data = chunks.next()
         except StopIteration:
-            pass
+            if self.tagname and self.required:
+                yield "<%s />" % (self.tagname,)
         else:
             if self.tagname:
                 yield "<%s>" % (self.tagname,)
@@ -660,8 +661,8 @@ class Dict(Field):
       print(obj2.name)
       print(mymodel.render(fragment = True))
 
-    The wrapper tag is rendered if the dict is not empty, and is transparent
-    for dict item access.
+    This wrapper tag is always rendered, even if the dict is empty.  It is
+    transparently removed when parsing.
     """
 
     class arguments(Field.arguments):
@@ -746,20 +747,21 @@ class Dict(Field):
     def parse_done(self, obj):
         items = self.__get__(obj)
         if self.minlength is not None and len(items) < self.minlength:
-            if self.required or len(items) != 0:
-                raise dexml.ParseError("Field '%s': not enough items" % (self.field_name,))
+            raise dexml.ParseError("Field '%s': not enough items" % (self.field_name,))
         if self.maxlength is not None and len(items) > self.maxlength:
             raise dexml.ParseError("Field '%s': too many items" % (self.field_name,))
 
     def render_children(self, obj, items, nsmap):
         if self.minlength is not None and len(items) < self.minlength:
-            if self.required and len(items) > 0:
-                raise dexml.RenderError("Field '%s': not enough items" % (self.field_name,))
+            raise dexml.RenderError("Field '%s': not enough items" % (self.field_name,))
         if self.maxlength is not None and len(items) > self.maxlength:
             raise dexml.RenderError("too many items")
         if self.tagname:
             children = "".join(data for item in items.values() for data in self.field.render_children(obj,item,nsmap))
-            if children:
+            if not children:
+                if self.required:
+                    yield "<%s />" % (self.tagname,)
+            else:
                 yield children.join(('<%s>'%self.tagname, '</%s>'%self.tagname))
         else:
             for item in items.values():
