@@ -114,9 +114,9 @@ class TestDexml(unittest.TestCase):
         class hello(dexml.Model):
             pass
 
-        self.assertRaises(dexml.XmlError,hello.parse,"<hello>")
-        self.assertRaises(dexml.XmlError,hello.parse,"<hello></helo>")
-        self.assertRaises(dexml.XmlError,hello.parse,"")
+        self.assertRaises(dexml.XmlError,hello.parse,b("<hello>"))
+        self.assertRaises(dexml.XmlError,hello.parse,b("<hello></helo>"))
+        self.assertRaises(dexml.XmlError,hello.parse,b(""))
 
         self.assertRaises(dexml.XmlError,hello.parse,u"")
         self.assertRaises(dexml.XmlError,hello.parse,u"<hello>")
@@ -165,6 +165,17 @@ class TestDexml(unittest.TestCase):
         self.assertEquals(h.render(encoding="utf8"),b("").join(h.irender(encoding="utf8")))
         self.assertEquals(h.render(encoding="utf8",fragment=True),b("").join(h.irender(encoding="utf8",fragment=True)))
 
+    def test_unicode_string_field(self):
+        """Test a dexml.Model class with a unicode string field."""
+        class Person(dexml.Model):
+            name = fields.String()
+
+        p = Person.parse(u"<Person name='hel\N{GREEK SMALL LETTER LAMDA}o'/>")
+        self.assertEquals(p.name, u"hel\N{GREEK SMALL LETTER LAMDA}o")
+
+        p = Person()
+        p.name = u"hel\N{GREEK SMALL LETTER LAMDA}o"
+        self.assertEquals(p.render(encoding="utf8"), u'<?xml version="1.0" encoding="utf8" ?><Person name="hel\N{GREEK SMALL LETTER LAMDA}o" />'.encode("utf8"))
 
     def test_model_meta_attributes(self):
         class hello(dexml.Model):
@@ -478,6 +489,15 @@ class TestDexml(unittest.TestCase):
         pets.meta.ignore_unknown_elements = False
         self.assertRaises(dexml.ParseError, pets.parse, "<pets><person name='ryan' age='26' /><pet name='riley' species='dog' /><reward date='February 23, 2010'/><reward date='November 10, 2009' /></pets>")
 
+    def test_list_field_tagname(self):
+        """Test List(tagname="items",required=True)."""
+        class obj(dexml.Model):
+            items = fields.List(fields.String(tagname="item"),tagname="items")
+        o = obj(items=[])
+        self.assertEquals(o.render(fragment=True), '<obj><items /></obj>')
+        self.assertRaises(dexml.ParseError,obj.parse,'<obj />')
+        o = obj.parse('<obj><items /></obj>')
+        self.assertEquals(o.items,[])
 
     def test_list_field_sanity_checks(self):
         class GreedyField(fields.Field):
@@ -552,6 +572,16 @@ class TestDexml(unittest.TestCase):
         del o.items['item2']
         self.assertEquals(o.render(fragment = True), '<obj><items><item name="item1"><attr>val1</attr></item></items></obj>')
 
+        # Test that wrapper tags are still required even for empty fields
+        o = obj(items={})
+        self.assertEquals(o.render(fragment=True), '<obj><items /></obj>')
+        o = obj.parse('<obj><items /></obj>')
+        self.assertEquals(o.items,{})
+        self.assertRaises(dexml.ParseError,obj.parse,'<obj />')
+        obj.items.required = False
+        self.assertEquals(o.render(fragment=True), '<obj />')
+        obj.items.required = True
+
         from collections import defaultdict
         class _dict(defaultdict):
             def __init__(self):
